==> haskell-hls-class-plugin-1.1.1.0-160-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-class-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-class-plugin
version:              1.1.1.0
visibility:           public
id:                   hls-class-plugin-1.1.1.0-BNtV7KAtkQrFmckVx8EXSx
key:                  hls-class-plugin-1.1.1.0-BNtV7KAtkQrFmckVx8EXSx
license:              Apache-2.0
maintainer:           jjc9310@gmail.com
author:               Junyoung Clare Jang
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:
    Class/instance management plugin for Haskell Language Server

description:
    Class/instance management plugin for Haskell Language Server.
    For usage, please see README of HLS on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  f253961c6a2a8f4618bcd625697f4703
exposed:              True
exposed-modules:      Ide.Plugin.Class
hidden-modules:
    Ide.Plugin.Class.CodeAction Ide.Plugin.Class.CodeLens
    Ide.Plugin.Class.ExactPrint Ide.Plugin.Class.Types
    Ide.Plugin.Class.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-class-plugin-1.1.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-class-plugin-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-class-plugin
hs-libraries:         HShls-class-plugin-1.1.1.0-BNtV7KAtkQrFmckVx8EXSx
depends:
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1
    extra-1.7.14-JZwVFNOTzAl9wNXhTRS6o8 ghc-9.2.8 ghc-boot-th-9.2.8
    ghc-exactprint-1.5.0-H8odI2cXixCDr77p62oh8G
    ghcide-1.9.1.0-HwAkVTDd37EFvNbRQNs88T
    hls-graph-1.9.0.0-4nTvQprVee21P1DngyVSFV
    hls-plugin-api-1.6.0.0-6Ebop0G4HfEC83Y5bnhsUu
    lens-5.2.3-Lr9JV2q3Rgv6Xn7f42cFjs
    lsp-1.6.0.0-1JAbQDnc0SK1hycTz4LLrJ text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-class-plugin/html/hls-class-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-class-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-class-plugin-1.1.1.1-16-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-class-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-class-plugin
version:              1.1.1.1
visibility:           public
id:                   hls-class-plugin-1.1.1.1-2fXrmC2jVtJpBaoloSdj5
key:                  hls-class-plugin-1.1.1.1-2fXrmC2jVtJpBaoloSdj5
license:              Apache-2.0
maintainer:           jjc9310@gmail.com
author:               Junyoung Clare Jang
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:
    Class/instance management plugin for Haskell Language Server

description:
    Class/instance management plugin for Haskell Language Server.
    For usage, please see README of HLS on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  c6a5e4a72118eaeb6176efdbf940ce5f
exposed:              True
exposed-modules:      Ide.Plugin.Class
hidden-modules:
    Ide.Plugin.Class.CodeAction Ide.Plugin.Class.CodeLens
    Ide.Plugin.Class.ExactPrint Ide.Plugin.Class.Types
    Ide.Plugin.Class.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-class-plugin-1.1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-class-plugin-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-class-plugin
hs-libraries:         HShls-class-plugin-1.1.1.1-2fXrmC2jVtJpBaoloSdj5
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1
    extra-1.7.15-9PmwGQvWkElDwGNWrixqMB ghc-9.2.8 ghc-boot-th-9.2.8
    ghc-exactprint-1.5.0-HXVoV4M5yQt8hu0DDQNuW5
    ghcide-1.10.0.0-42asgJmBwLYDXfQ3kee4Wu
    hls-graph-1.9.0.0-7y2pZvkYmIwHHyfFLNsbki
    hls-plugin-api-1.6.0.0-GBhVrEAXY9G7a8rlmXAPNi
    lens-5.2.3-JhnKgAx9k76Jin0xTqnLw0
    lsp-1.6.0.0-3mgfXrOs4nYBY8raCTSUiO text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-class-plugin/html/hls-class-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-class-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
